@@ -54,8 +54,7 @@ static void XimGetWindowPosition(void* arg, FcitxInputContext* ic, int* x, int*
 static void XimUpdatePreedit(void* arg, FcitxInputContext* ic);
 
 static Bool XimProtocolHandler(XIMS _ims, IMProtocol * call_data);
-static void SetTriggerKeys (FcitxXimFrontend* xim, char** strKey, int length);
-static inline Bool MyStrcmp (char *str1, char *str2);
+static inline Bool MyStrcmp(char *str1, char *str2);
 
 static XIMStyle OverTheSpot_Styles[] = {
     XIMPreeditPosition | XIMStatusArea, //OverTheSpot
@@ -71,18 +70,17 @@ static XIMStyle OverTheSpot_Styles[] = {
 };
 
 static XIMStyle OnTheSpot_Styles [] = {
-        XIMPreeditPosition | XIMStatusNothing,
-        XIMPreeditCallbacks | XIMStatusNothing,
-        XIMPreeditNothing | XIMStatusNothing,
-        XIMPreeditPosition | XIMStatusCallbacks,
-        XIMPreeditCallbacks | XIMStatusCallbacks,
-        XIMPreeditNothing | XIMStatusCallbacks,
-        0
-    };
+    XIMPreeditPosition | XIMStatusNothing,
+    XIMPreeditCallbacks | XIMStatusNothing,
+    XIMPreeditNothing | XIMStatusNothing,
+    XIMPreeditPosition | XIMStatusCallbacks,
+    XIMPreeditCallbacks | XIMStatusCallbacks,
+    XIMPreeditNothing | XIMStatusCallbacks,
+    0
+};
 
 FCITX_EXPORT_API
-FcitxFrontend frontend =
-{
+FcitxFrontend frontend = {
     XimCreate,
     XimDestroy,
     XimCreateIC,
@@ -97,10 +95,13 @@ FcitxFrontend frontend =
     XimUpdatePreedit,
     NULL,
     NULL,
-    NULL,
+    XimCheckICFromSameApplication,
     NULL
 };
 
+FCITX_EXPORT_API
+int ABI_VERSION = FCITX_ABI_VERSION;
+
 FcitxXimFrontend *ximfrontend;
 
 CONFIG_DESC_DEFINE(GetXimConfigDesc, "fcitx-xim.desc")
@@ -113,9 +114,9 @@ static XIMEncoding zhEncodings[] = {
 
 char strLocale[201] = "zh_CN.GB18030,zh_CN.GB2312,zh_CN,zh_CN.GBK,zh_CN.UTF-8,zh_CN.UTF8,en_US.UTF-8,en_US.UTF8";
 
-Bool MyStrcmp (char *str1, char *str2)
+Bool MyStrcmp(char *str1, char *str2)
 {
-    return !strncmp (str1, str2, strlen (str2));
+    return !strncmp(str1, str2, strlen(str2));
 }
 
 void* XimCreate(FcitxInstance* instance, int frontendid)
@@ -129,18 +130,14 @@ void* XimCreate(FcitxInstance* instance, int frontendid)
     ximfrontend = xim;
 
     XIMStyles *input_styles;
-    XIMTriggerKeys *on_keys;
     XIMEncodings *encodings;
     char *imname = NULL;
-    GenericConfig *fc = &instance->config->gconfig;
-    ConfigValueType triggerKey = ConfigGetBindValue(fc, "Hotkey", "TriggerKey");
     char *p;
     FcitxModuleFunctionArg arg;
 
     xim->display = InvokeFunction(instance, FCITX_X11, GETDISPLAY, arg);
 
-    if (xim->display == NULL)
-    {
+    if (xim->display == NULL) {
         FcitxLog(FATAL, _("X11 not initialized"));
         free(xim);
         return NULL;
@@ -172,20 +169,9 @@ void* XimCreate(FcitxInstance* instance, int frontendid)
         }
     }
 
-    char *strkey[2];
-    int i = 0;
-    for (;i<2;i++)
-    {
-        if (triggerKey.hotkey[i].desc == NULL)
-            break;
-        strkey[i] = triggerKey.hotkey[i].desc;
-    }
-    SetTriggerKeys(xim, strkey, i);
-
     if (GetXimConfigDesc() == NULL)
         xim->bUseOnTheSpotStyle = false;
-    else
-    {
+    else {
         ConfigFileDesc* configDesc = GetXimConfigDesc();
 
         FILE *fp;
@@ -194,8 +180,7 @@ void* XimCreate(FcitxInstance* instance, int frontendid)
         FcitxLog(DEBUG, "Load Config File %s", file);
         free(file);
         if (!fp) {
-            if (errno == ENOENT)
-            {
+            if (errno == ENOENT) {
                 char *file;
                 FILE *fp2 = GetXDGFileUserWithPrefix("conf", "fcitx-xim.config", "wt", &file);
                 FcitxLog(DEBUG, "Save Config to %s", file);
@@ -216,21 +201,14 @@ void* XimCreate(FcitxInstance* instance, int frontendid)
     }
 
     input_styles = (XIMStyles *) malloc(sizeof(XIMStyles));
-    if (xim->bUseOnTheSpotStyle)
-    {
+    if (xim->bUseOnTheSpotStyle) {
         input_styles->count_styles = sizeof(OnTheSpot_Styles) / sizeof(XIMStyle) - 1;
         input_styles->supported_styles = OnTheSpot_Styles;
-    }
-    else
-    {
+    } else {
         input_styles->count_styles = sizeof(OverTheSpot_Styles) / sizeof(XIMStyle) - 1;
         input_styles->supported_styles = OverTheSpot_Styles;
     }
 
-    on_keys = (XIMTriggerKeys *) malloc(sizeof(XIMTriggerKeys));
-    on_keys->count_keys = xim->iTriggerKeyCount + 1;
-    on_keys->keylist = xim->Trigger_Keys;
-
     encodings = (XIMEncodings *) malloc(sizeof(XIMEncodings));
     encodings->count_encodings = sizeof(zhEncodings) / sizeof(XIMEncoding) - 1;
     encodings->supported_encodings = zhEncodings;
@@ -258,11 +236,9 @@ void* XimCreate(FcitxInstance* instance, int frontendid)
                         IMEncodingList, encodings,
                         IMProtocolHandler, XimProtocolHandler,
                         IMFilterEventMask, KeyPressMask | KeyReleaseMask,
-                        IMOnKeysList, on_keys,
                         NULL);
 
     free(input_styles);
-    free(on_keys);
     free(encodings);
 
     if (xim->ims == (XIMS) NULL) {
@@ -371,86 +347,6 @@ boolean XimDestroy(void* arg)
     return true;
 }
 
-void SetTriggerKeys (FcitxXimFrontend* xim, char **strKey, int length)
-{
-    int             i;
-    char           *p;
-
-    if (length == 0)
-    {
-        strKey[0] = "CTRL_SPACE";
-        length = 1;
-    }
-
-    xim->iTriggerKeyCount = length - 1;
-
-    if (xim->Trigger_Keys)
-        free(xim->Trigger_Keys);
-
-    xim->Trigger_Keys = (XIMTriggerKey *) malloc (sizeof (XIMTriggerKey) * (xim->iTriggerKeyCount + 2));
-    for (i = 0; i <= (xim->iTriggerKeyCount + 1); i++) {
-        xim->Trigger_Keys[i].keysym = 0;
-        xim->Trigger_Keys[i].modifier = 0;
-        xim->Trigger_Keys[i].modifier_mask = 0;
-    }
-
-    for (i = 0; i <= xim->iTriggerKeyCount; i++) {
-        if (MyStrcmp (strKey[i], "CTRL_")) {
-            xim->Trigger_Keys[i].modifier = xim->Trigger_Keys[i].modifier | ControlMask;
-            xim->Trigger_Keys[i].modifier_mask = xim->Trigger_Keys[i].modifier_mask | ControlMask;
-        }
-        else if (MyStrcmp (strKey[i], "SHIFT_")) {
-            xim->Trigger_Keys[i].modifier = xim->Trigger_Keys[i].modifier | ShiftMask;
-            xim->Trigger_Keys[i].modifier_mask = xim->Trigger_Keys[i].modifier_mask | ShiftMask;
-        }
-        else if (MyStrcmp (strKey[i], "ALT_")) {
-            xim->Trigger_Keys[i].modifier = xim->Trigger_Keys[i].modifier | Mod1Mask;
-            xim->Trigger_Keys[i].modifier_mask = xim->Trigger_Keys[i].modifier_mask | Mod1Mask;
-        }
-        else if (MyStrcmp (strKey[i], "SUPER_")) {
-            xim->Trigger_Keys[i].modifier = xim->Trigger_Keys[i].modifier | Mod4Mask;
-            xim->Trigger_Keys[i].modifier_mask = xim->Trigger_Keys[i].modifier_mask | Mod4Mask;
-        }
-
-        if (xim->Trigger_Keys[i].modifier == 0) {
-            xim->Trigger_Keys[i].modifier = ControlMask;
-            xim->Trigger_Keys[i].modifier_mask = ControlMask;
-        }
-
-        p = strKey[i] + strlen (strKey[i]) - 1;
-        while (*p != '_') {
-            p--;
-            if (p == strKey[i] || (p == strKey[i] + strlen (strKey[i]) - 1)) {
-                xim->Trigger_Keys = (XIMTriggerKey *) malloc (sizeof (XIMTriggerKey) * (xim->iTriggerKeyCount + 2));
-                xim->Trigger_Keys[i].keysym = XK_space;
-                return;
-            }
-        }
-        p++;
-
-        if (strlen (p) == 1)
-            xim->Trigger_Keys[i].keysym = tolower (*p);
-        else if (!strcasecmp (p, "LCTRL"))
-            xim->Trigger_Keys[i].keysym = XK_Control_L;
-        else if (!strcasecmp (p, "RCTRL"))
-            xim->Trigger_Keys[i].keysym = XK_Control_R;
-        else if (!strcasecmp (p, "LSHIFT"))
-            xim->Trigger_Keys[i].keysym = XK_Shift_L;
-        else if (!strcasecmp (p, "RSHIFT"))
-            xim->Trigger_Keys[i].keysym = XK_Shift_R;
-        else if (!strcasecmp (p, "LALT"))
-            xim->Trigger_Keys[i].keysym = XK_Alt_L;
-        else if (!strcasecmp (p, "RALT"))
-            xim->Trigger_Keys[i].keysym = XK_Alt_R;
-        else if (!strcasecmp (p, "LSUPER"))
-            xim->Trigger_Keys[i].keysym = XK_Super_L;
-        else if (!strcasecmp (p, "RSUPER"))
-            xim->Trigger_Keys[i].keysym = XK_Super_R;
-        else
-            xim->Trigger_Keys[i].keysym = XK_space;
-    }
-}
-
 void XimEnableIM(void* arg, FcitxInputContext* ic)
 {
     FcitxXimFrontend* xim = (FcitxXimFrontend*) arg;
@@ -461,7 +357,6 @@ void XimEnableIM(void* arg, FcitxInputContext* ic)
     IMPreeditStart(xim->ims, (XPointer) &call_data);
 }
 
-
 void XimCloseIM(void* arg, FcitxInputContext* ic)
 {
     FcitxXimFrontend* xim = (FcitxXimFrontend*) arg;
@@ -489,8 +384,8 @@ void XimCommitString(void* arg, FcitxInputContext* ic, char* str)
      * quite strange.
      */
     if (GetXimIC(ic)->bPreeditStarted == true) {
-        XimPreeditCallbackDraw (xim, GetXimIC(ic), "", 0);
-        XimPreeditCallbackDone (xim, GetXimIC(ic));
+        XimPreeditCallbackDraw(xim, GetXimIC(ic), "", 0);
+        XimPreeditCallbackDone(xim, GetXimIC(ic));
         GetXimIC(ic)->bPreeditStarted = false;
     }
 
@@ -511,7 +406,7 @@ void XimForwardKey(void *arg, FcitxInputContext* ic, FcitxKeyEventType event, Fc
     FcitxXimFrontend* xim = (FcitxXimFrontend*) arg;
     XEvent xEvent;
 
-    xEvent.xkey.type = (event == FCITX_PRESS_KEY)?KeyPress:KeyRelease;
+    xEvent.xkey.type = (event == FCITX_PRESS_KEY) ? KeyPress : KeyRelease;
     xEvent.xkey.display = xim->display;
     xEvent.xkey.serial = xim->currentSerialNumberKey;
     xEvent.xkey.send_event = False;
@@ -540,8 +435,7 @@ void XimSetWindowOffset(void* arg, FcitxInputContext* ic, int x, int y)
     else if (ximic->client_win)
         window = ximic->client_win;
 
-    if (window != None)
-    {
+    if (window != None) {
         XTranslateCoordinates(xim->display, RootWindow(xim->display, xim->iScreen), window,
                               x, y,
                               &ic->offset_x, &ic->offset_y,
@@ -552,33 +446,33 @@ void XimSetWindowOffset(void* arg, FcitxInputContext* ic, int x, int y)
 
 void XimGetWindowPosition(void* arg, FcitxInputContext* ic, int* x, int* y)
 {
-    *x= ic->offset_x;
-    *y= ic->offset_y;
+    *x = ic->offset_x;
+    *y = ic->offset_y;
 }
 
 void XimUpdatePreedit(void* arg, FcitxInputContext* ic)
 {
     FcitxXimFrontend* xim = (FcitxXimFrontend*) arg;
-    char* strPreedit = MessagesToCString(xim->owner->input.msgPreedit);
+    FcitxInputState* input = FcitxInstanceGetInputState(xim->owner);
+    char* strPreedit = MessagesToCString(FcitxInputStateGetClientPreedit(input));
     char* str = ProcessOutputFilter(xim->owner, strPreedit);
-    if (str)
-    {
+    if (str) {
         free(strPreedit);
         strPreedit = str;
     }
 
     if (strlen(strPreedit) == 0 && GetXimIC(ic)->bPreeditStarted == true) {
-        XimPreeditCallbackDraw (xim, GetXimIC(ic), strPreedit, 0);
-        XimPreeditCallbackDone (xim, GetXimIC(ic));
+        XimPreeditCallbackDraw(xim, GetXimIC(ic), strPreedit, 0);
+        XimPreeditCallbackDone(xim, GetXimIC(ic));
         GetXimIC(ic)->bPreeditStarted = false;
     }
 
     if (strlen(strPreedit) != 0 && GetXimIC(ic)->bPreeditStarted == false) {
-        XimPreeditCallbackStart (xim, GetXimIC(ic));
+        XimPreeditCallbackStart(xim, GetXimIC(ic));
         GetXimIC(ic)->bPreeditStarted = true;
     }
     if (strlen(strPreedit) != 0) {
-        XimPreeditCallbackDraw (xim, GetXimIC(ic), strPreedit, xim->owner->input.iCursorPos);
+        XimPreeditCallbackDraw(xim, GetXimIC(ic), strPreedit, FcitxInputStateGetCursorPos(input));
     }
 
     free(strPreedit);
