@@ -65,10 +65,8 @@ void InitMainWindow(MainWindow* mainWindow)
     Visual * vs;
     XSetWindowAttributes attrib;
     unsigned long   attribmask;
-    GC gc;
     char        strWindowName[] = "Fcitx Main Window";
     int swidth, sheight;
-    XGCValues xgv;
     Display* dpy = classicui->dpy;
     int iScreen = classicui->iScreen;
     FcitxSkin *sc = &classicui->skin;
@@ -79,49 +77,42 @@ void InitMainWindow(MainWindow* mainWindow)
 
     vs = ClassicUIFindARGBVisual(classicui);
 
-    if (classicui->iMainWindowOffsetX + cairo_image_surface_get_width(back->image) > swidth )
+    if (classicui->iMainWindowOffsetX + cairo_image_surface_get_width(back->image) > swidth)
         classicui->iMainWindowOffsetX = swidth - cairo_image_surface_get_width(back->image);
 
-    if (classicui->iMainWindowOffsetY + cairo_image_surface_get_height(back->image) > sheight )
+    if (classicui->iMainWindowOffsetY + cairo_image_surface_get_height(back->image) > sheight)
         classicui->iMainWindowOffsetY = sheight - cairo_image_surface_get_height(back->image);
 
     ClassicUIInitWindowAttribute(classicui, &vs, &cmap, &attrib, &attribmask, &depth);
-    mainWindow->window=XCreateWindow (dpy,
-                                      RootWindow(dpy, iScreen),
-                                      classicui->iMainWindowOffsetX,
-                                      classicui->iMainWindowOffsetY,
-                                      cairo_image_surface_get_width(back->image),
-                                      cairo_image_surface_get_height(back->image),
-                                      0, depth,InputOutput, vs,attribmask, &attrib);
+    mainWindow->window = XCreateWindow(dpy,
+                                       RootWindow(dpy, iScreen),
+                                       classicui->iMainWindowOffsetX,
+                                       classicui->iMainWindowOffsetY,
+                                       cairo_image_surface_get_width(back->image),
+                                       cairo_image_surface_get_height(back->image),
+                                       0, depth, InputOutput, vs, attribmask, &attrib);
 
     if (mainWindow->window == None)
         return;
 
-    xgv.foreground = WhitePixel(dpy, iScreen);
-    mainWindow->pm_main_bar = XCreatePixmap(
-                                  dpy,
-                                  mainWindow->window,
-                                  MAIN_BAR_MAX_WIDTH,
-                                  MAIN_BAR_MAX_HEIGHT,
-                                  depth);
-    gc = XCreateGC(dpy,mainWindow->pm_main_bar, GCForeground, &xgv);
-    XFillRectangle(dpy, mainWindow->pm_main_bar, gc, 0, 0,cairo_image_surface_get_width(back->image), cairo_image_surface_get_height(back->image));
-    mainWindow->cs_main_bar=cairo_xlib_surface_create(
-                                dpy,
-                                mainWindow->pm_main_bar,
-                                vs,
-                                MAIN_BAR_MAX_WIDTH,
-                                MAIN_BAR_MAX_HEIGHT);
-    XFreeGC(dpy,gc);
+    mainWindow->cs_x_main_bar = cairo_xlib_surface_create(
+                                    dpy,
+                                    mainWindow->window,
+                                    vs,
+                                    MAIN_BAR_MAX_WIDTH,
+                                    MAIN_BAR_MAX_HEIGHT);
+    mainWindow->cs_main_bar = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,
+                              MAIN_BAR_MAX_WIDTH,
+                              MAIN_BAR_MAX_HEIGHT);
 
-    mainWindow->main_win_gc = XCreateGC( dpy, mainWindow->window, 0, NULL );
-    XChangeWindowAttributes (dpy, mainWindow->window, attribmask, &attrib);
-    XSelectInput (dpy, mainWindow->window, ExposureMask | ButtonPressMask | ButtonReleaseMask  | PointerMotionMask | LeaveWindowMask);
+    mainWindow->main_win_gc = XCreateGC(dpy, mainWindow->window, 0, NULL);
+    XChangeWindowAttributes(dpy, mainWindow->window, attribmask, &attrib);
+    XSelectInput(dpy, mainWindow->window, ExposureMask | ButtonPressMask | ButtonReleaseMask  | PointerMotionMask | LeaveWindowMask);
 
     ClassicUISetWindowProperty(classicui, mainWindow-> window, FCITX_WINDOW_DOCK, strWindowName);
 }
 
-MainWindow* CreateMainWindow (FcitxClassicUI* classicui)
+MainWindow* CreateMainWindow(FcitxClassicUI* classicui)
 {
     MainWindow *mainWindow;
 
@@ -140,55 +131,54 @@ MainWindow* CreateMainWindow (FcitxClassicUI* classicui)
     return mainWindow;
 }
 
-void DisplayMainWindow (Display* dpy, MainWindow* mainWindow)
+void DisplayMainWindow(Display* dpy, MainWindow* mainWindow)
 {
     FcitxLog(DEBUG, _("DISPLAY MainWindow"));
 
     if (!mainWindow->bMainWindowHidden)
-        XMapRaised (dpy, mainWindow->window);
+        XMapRaised(dpy, mainWindow->window);
 }
 
-void DrawMainWindow (MainWindow* mainWindow)
+void DrawMainWindow(MainWindow* mainWindow)
 {
     FcitxSkin *sc = &mainWindow->owner->skin;
     FcitxInstance *instance = mainWindow->owner->owner;
-    cairo_t *c;
 
-    if ( mainWindow->bMainWindowHidden )
+    if (mainWindow->bMainWindowHidden)
         return;
 
     FcitxLog(DEBUG, _("DRAW MainWindow"));
 
-    c=cairo_create(mainWindow->cs_main_bar);
-    //把背景清空
-    cairo_save(c);
-    cairo_set_source_rgba(c, 0, 0, 0,0);
-    cairo_rectangle (c, 0, 0, SIZEX, SIZEY);
-    cairo_set_operator(c, CAIRO_OPERATOR_SOURCE);
-    cairo_fill(c);
-    cairo_restore(c);
+    if (mainWindow->owner->hideMainWindow == HM_SHOW || (mainWindow->owner->hideMainWindow == HM_AUTO && (GetCurrentState(mainWindow->owner->owner) != IS_CLOSED))) {
+        cairo_t *c;
 
-    cairo_set_operator(c, CAIRO_OPERATOR_OVER);
+        c = cairo_create(mainWindow->cs_main_bar);
+        //把背景清空
+        cairo_save(c);
+        cairo_set_source_rgba(c, 0, 0, 0, 0);
+        cairo_rectangle(c, 0, 0, SIZEX, SIZEY);
+        cairo_set_operator(c, CAIRO_OPERATOR_SOURCE);
+        cairo_fill(c);
+        cairo_restore(c);
 
-    if (mainWindow->owner->hideMainWindow == HM_SHOW || (mainWindow->owner->hideMainWindow == HM_AUTO && (GetCurrentState(mainWindow->owner->owner) != IS_CLOSED)))
-    {
+        cairo_set_operator(c, CAIRO_OPERATOR_OVER);
+        int width = 0, height = 0;
         /* Check placement */
-        if (utarray_len(&mainWindow->owner->skin.skinMainBar.skinPlacement) != 0)
-        {
+        if (utarray_len(&mainWindow->owner->skin.skinMainBar.skinPlacement) != 0) {
             SkinImage* back = LoadImage(sc, sc->skinMainBar.backImg, false);
             if (back == NULL)
                 return;
-            int width = cairo_image_surface_get_width(back->image);
-            int height = cairo_image_surface_get_height(back->image);
+            width = cairo_image_surface_get_width(back->image);
+            height = cairo_image_surface_get_height(back->image);
             XResizeWindow(mainWindow->dpy, mainWindow->window, width, height);
             DrawResizableBackground(c, back->image, height, width, 0, 0, 0, 0, F_RESIZE, F_COPY);
 
             FcitxUIStatus* status;
-            for (status = (FcitxUIStatus*) utarray_front(&instance->uistats);
+            UT_array* uistats = FcitxInstanceGetUIStats(instance);
+            for (status = (FcitxUIStatus*) utarray_front(uistats);
                     status != NULL;
-                    status = (FcitxUIStatus*) utarray_next(&instance->uistats, status)
-                )
-            {
+                    status = (FcitxUIStatus*) utarray_next(uistats, status)
+                ) {
                 FcitxClassicUIStatus* privstat = GetPrivateStatus(status);
                 if (privstat == NULL)
                     continue;
@@ -200,39 +190,30 @@ void DrawMainWindow (MainWindow* mainWindow)
             SkinPlacement* sp;
             for (sp = (SkinPlacement*) utarray_front(&sc->skinMainBar.skinPlacement);
                     sp != NULL;
-                    sp = (SkinPlacement*) utarray_next(&sc->skinMainBar.skinPlacement, sp))
-            {
-                if (strcmp(sp->name, "logo") == 0)
-                {
+                    sp = (SkinPlacement*) utarray_next(&sc->skinMainBar.skinPlacement, sp)) {
+                if (strcmp(sp->name, "logo") == 0) {
                     SkinImage* logo = LoadImage(sc, sc->skinMainBar.logo, false);
-                    if (logo)
-                    {
+                    if (logo) {
                         DrawImage(c, logo->image, sp->x, sp->y, mainWindow->logostat.mouse);
-                        UpdateStatusGeometry( &mainWindow->logostat, logo, sp->x, sp->y);
+                        UpdateStatusGeometry(&mainWindow->logostat, logo, sp->x, sp->y);
                     }
-                }
-                else if (strcmp(sp->name, "im") == 0)
-                {
+                } else if (strcmp(sp->name, "im") == 0) {
                     SkinImage* imicon = NULL;
-                    if (GetCurrentState(instance) != IS_ACTIVE )
+                    if (GetCurrentState(instance) != IS_ACTIVE || GetCurrentIM(instance) == NULL)
                         imicon = LoadImage(sc, sc->skinMainBar.eng, false);
-                    else
-                    {
+                    else {
                         FcitxIM* im = GetCurrentIM(instance);
                         char path[PATH_MAX];
-                        snprintf(path, PATH_MAX, "%s.png", im->strIconName );
+                        snprintf(path, PATH_MAX, "%s.png", im->strIconName);
                         imicon = LoadImage(sc, path, false);
                         if (imicon == NULL)
                             imicon = LoadImage(sc, sc->skinMainBar.active, false);
                     }
                     DrawImage(c, imicon->image, sp->x, sp->y, mainWindow->imiconstat.mouse);
-                    UpdateStatusGeometry( &mainWindow->imiconstat, imicon, sp->x, sp->y);
-                }
-                else
-                {
+                    UpdateStatusGeometry(&mainWindow->imiconstat, imicon, sp->x, sp->y);
+                } else {
                     status = GetUIStatus(instance, sp->name);
-                    if (status)
-                    {
+                    if (status) {
                         FcitxClassicUIStatus* privstat = GetPrivateStatus(status);
                         if (privstat == NULL)
                             continue;
@@ -240,44 +221,38 @@ void DrawMainWindow (MainWindow* mainWindow)
                         boolean active = status->getCurrentStatus(status->arg);
                         char path[PATH_MAX];
                         if (active)
-                            snprintf(path, PATH_MAX, "%s_active.png", status->name );
+                            snprintf(path, PATH_MAX, "%s_active.png", status->name);
                         else
-                            snprintf(path, PATH_MAX, "%s_inactive.png", status->name );
+                            snprintf(path, PATH_MAX, "%s_inactive.png", status->name);
                         SkinImage* statusicon = LoadImage(sc, path, false);
                         if (statusicon == NULL)
                             continue;
                         DrawImage(c, statusicon->image, sp->x, sp->y, privstat->mouse);
-                        UpdateStatusGeometry( privstat, statusicon, sp->x, sp->y);
+                        UpdateStatusGeometry(privstat, statusicon, sp->x, sp->y);
                     }
                 }
             }
-            XCopyArea (mainWindow->dpy, mainWindow->pm_main_bar, mainWindow->window, mainWindow->main_win_gc, 0, 0, width,
-                       height, 0, 0);
-        }
-        else
-        {
+        } else {
             /* Only logo and input status is hard-code, other should be status */
             int currentX = sc->skinMainBar.marginLeft;
-            int height = 0;
+            height = 0;
             SkinImage* back = LoadImage(sc, sc->skinMainBar.backImg, false);
             SkinImage* logo = LoadImage(sc, sc->skinMainBar.logo, false);
             SkinImage* imicon;
             int imageheight;
-            if (logo)
-            {
+            if (logo) {
                 currentX += cairo_image_surface_get_width(logo->image);
                 imageheight = cairo_image_surface_get_height(logo->image);
                 if (imageheight > height)
                     height = imageheight;
             }
 
-            if (GetCurrentState(instance) != IS_ACTIVE )
+            if (GetCurrentState(instance) != IS_ACTIVE || GetCurrentIM(instance) == NULL)
                 imicon = LoadImage(sc, sc->skinMainBar.eng, false);
-            else
-            {
+            else {
                 FcitxIM* im = GetCurrentIM(instance);
                 char path[PATH_MAX];
-                snprintf(path, PATH_MAX, "%s.png", im->strIconName );
+                snprintf(path, PATH_MAX, "%s.png", im->strIconName);
                 imicon = LoadImage(sc, path, false);
                 if (imicon == NULL)
                     imicon = LoadImage(sc, sc->skinMainBar.active, false);
@@ -288,17 +263,17 @@ void DrawMainWindow (MainWindow* mainWindow)
                 height = imageheight;
 
             FcitxUIStatus* status;
-            for (status = (FcitxUIStatus*) utarray_front(&instance->uistats);
+            UT_array* uistats = FcitxInstanceGetUIStats(instance);
+            for (status = (FcitxUIStatus*) utarray_front(uistats);
                     status != NULL;
-                    status = (FcitxUIStatus*) utarray_next(&instance->uistats, status)
-                )
-            {
+                    status = (FcitxUIStatus*) utarray_next(uistats, status)
+                ) {
                 boolean active = status->getCurrentStatus(status->arg);
                 char path[PATH_MAX];
                 if (active)
-                    snprintf(path, PATH_MAX, "%s_active.png", status->name );
+                    snprintf(path, PATH_MAX, "%s_active.png", status->name);
                 else
-                    snprintf(path, PATH_MAX, "%s_inactive.png", status->name );
+                    snprintf(path, PATH_MAX, "%s_inactive.png", status->name);
                 SkinImage* statusicon = LoadImage(sc, path, false);
                 if (statusicon == NULL)
                     continue;
@@ -308,7 +283,7 @@ void DrawMainWindow (MainWindow* mainWindow)
                     height = imageheight;
             }
 
-            int width = currentX + sc->skinMainBar.marginRight;
+            width = currentX + sc->skinMainBar.marginRight;
             height += sc->skinMainBar.marginTop + sc->skinMainBar.marginBottom;
 
             XResizeWindow(mainWindow->dpy, mainWindow->window, width, height);
@@ -325,21 +300,19 @@ void DrawMainWindow (MainWindow* mainWindow)
                                    );
 
             currentX = sc->skinMainBar.marginLeft;
-            if (logo)
-            {
+            if (logo) {
                 DrawImage(c, logo->image, currentX, sc->skinMainBar.marginTop, mainWindow->logostat.mouse);
-                UpdateStatusGeometry( &mainWindow->logostat, logo, currentX, sc->skinMainBar.marginTop);
+                UpdateStatusGeometry(&mainWindow->logostat, logo, currentX, sc->skinMainBar.marginTop);
                 currentX += cairo_image_surface_get_width(logo->image);
             }
             DrawImage(c, imicon->image, currentX, sc->skinMainBar.marginTop, mainWindow->imiconstat.mouse);
-            UpdateStatusGeometry( &mainWindow->imiconstat, imicon, currentX, sc->skinMainBar.marginTop);
+            UpdateStatusGeometry(&mainWindow->imiconstat, imicon, currentX, sc->skinMainBar.marginTop);
             currentX += cairo_image_surface_get_width(imicon->image);
 
-            for (status = (FcitxUIStatus*) utarray_front(&instance->uistats);
+            for (status = (FcitxUIStatus*) utarray_front(uistats);
                     status != NULL;
-                    status = (FcitxUIStatus*) utarray_next(&instance->uistats, status)
-                )
-            {
+                    status = (FcitxUIStatus*) utarray_next(uistats, status)
+                ) {
                 FcitxClassicUIStatus* privstat = GetPrivateStatus(status);
                 if (privstat == NULL)
                     continue;
@@ -349,9 +322,9 @@ void DrawMainWindow (MainWindow* mainWindow)
                 boolean active = status->getCurrentStatus(status->arg);
                 char path[PATH_MAX];
                 if (active)
-                    snprintf(path, PATH_MAX, "%s_active.png", status->name );
+                    snprintf(path, PATH_MAX, "%s_active.png", status->name);
                 else
-                    snprintf(path, PATH_MAX, "%s_inactive.png", status->name );
+                    snprintf(path, PATH_MAX, "%s_inactive.png", status->name);
                 SkinImage* statusicon = LoadImage(sc, path, false);
                 if (statusicon == NULL)
                     continue;
@@ -359,15 +332,26 @@ void DrawMainWindow (MainWindow* mainWindow)
                 UpdateStatusGeometry(privstat, statusicon, currentX, sc->skinMainBar.marginTop);
                 currentX += cairo_image_surface_get_width(statusicon->image);
             }
-
-            XCopyArea (mainWindow->dpy, mainWindow->pm_main_bar, mainWindow->window, mainWindow->main_win_gc, 0, 0, width,
-                       height, 0, 0);
         }
-    }
-    else
-        XUnmapWindow (mainWindow->dpy, mainWindow->window);
 
-    cairo_destroy(c);
+        cairo_destroy(c);
+        {
+            cairo_xlib_surface_set_size(mainWindow->cs_x_main_bar,
+                                        width,
+                                        height);
+
+            c = cairo_create(mainWindow->cs_x_main_bar);
+            cairo_set_operator(c, CAIRO_OPERATOR_SOURCE);
+            cairo_set_source_surface(c, mainWindow->cs_main_bar, 0, 0);
+            cairo_rectangle(c, 0, 0, width, height);
+            cairo_clip(c);
+            cairo_paint(c);
+            cairo_destroy(c);
+        }
+
+        XMapRaised(mainWindow->dpy, mainWindow->window);
+    } else
+        XUnmapWindow(mainWindow->dpy, mainWindow->window);
 }
 
 void ReloadMainWindow(void *arg, boolean enabled)
@@ -375,19 +359,19 @@ void ReloadMainWindow(void *arg, boolean enabled)
     MainWindow* mainWindow = (MainWindow*) arg;
     boolean visable = WindowIsVisable(mainWindow->dpy, mainWindow->window);
     cairo_surface_destroy(mainWindow->cs_main_bar);
-    XFreePixmap(mainWindow->dpy, mainWindow->pm_main_bar);
+    cairo_surface_destroy(mainWindow->cs_x_main_bar);
     XFreeGC(mainWindow->dpy, mainWindow->main_win_gc);
     XDestroyWindow(mainWindow->dpy, mainWindow->window);
 
     mainWindow->cs_main_bar = NULL;
-    mainWindow->pm_main_bar = None;
+    mainWindow->cs_x_main_bar = NULL;
     mainWindow->main_win_gc = NULL;
     mainWindow->window = None;
 
     InitMainWindow(mainWindow);
 
     if (visable)
-        ShowMainWindow(mainWindow);
+        DrawMainWindow(mainWindow);
 }
 
 void UpdateStatusGeometry(FcitxClassicUIStatus *privstat, SkinImage *image, int x, int y)
@@ -398,54 +382,42 @@ void UpdateStatusGeometry(FcitxClassicUIStatus *privstat, SkinImage *image, int
     privstat->h = cairo_image_surface_get_height(image->image);
 }
 
-void ShowMainWindow(MainWindow* mainWindow)
-{
-    XMapRaised (mainWindow->dpy, mainWindow->window);
-}
-
 void CloseMainWindow(MainWindow *mainWindow)
 {
-    XUnmapWindow (mainWindow->dpy, mainWindow->window);
+    XUnmapWindow(mainWindow->dpy, mainWindow->window);
 }
 
 boolean SetMouseStatus(MainWindow *mainWindow, MouseE* mouseE, MouseE value, MouseE other)
 {
     FcitxInstance *instance = mainWindow->owner->owner;
     boolean changed = false;
-    if (mouseE != &mainWindow->logostat.mouse)
-    {
-        if (mainWindow->logostat.mouse != other)
-        {
+    if (mouseE != &mainWindow->logostat.mouse) {
+        if (mainWindow->logostat.mouse != other) {
             changed = true;
             mainWindow->logostat.mouse = other;
         }
     }
-    if (mouseE != &mainWindow->imiconstat.mouse)
-    {
-        if (mainWindow->imiconstat.mouse != other)
-        {
+    if (mouseE != &mainWindow->imiconstat.mouse) {
+        if (mainWindow->imiconstat.mouse != other) {
             changed = true;
             mainWindow->imiconstat.mouse = other;
         }
     }
     FcitxUIStatus *status;
-    for (status = (FcitxUIStatus*) utarray_front(&instance->uistats);
+    UT_array* uistats = FcitxInstanceGetUIStats(instance);
+    for (status = (FcitxUIStatus*) utarray_front(uistats);
             status != NULL;
-            status = (FcitxUIStatus*) utarray_next(&instance->uistats, status)
-        )
-    {
+            status = (FcitxUIStatus*) utarray_next(uistats, status)
+        ) {
         FcitxClassicUIStatus* privstat = GetPrivateStatus(status);
-        if (mouseE != &privstat->mouse)
-        {
-            if (privstat->mouse != other)
-            {
+        if (mouseE != &privstat->mouse) {
+            if (privstat->mouse != other) {
                 changed = true;
                 privstat->mouse = other;
             }
         }
     }
-    if (mouseE != NULL && *mouseE != value)
-    {
+    if (mouseE != NULL && *mouseE != value) {
         changed = true;
         *mouseE = value;
     }
@@ -460,10 +432,8 @@ boolean MainWindowEventHandler(void *arg, XEvent* event)
     FcitxClassicUI *classicui = mainWindow->owner;
     MouseE *mouse;
 
-    if (event->xany.window == mainWindow->window)
-    {
-        switch (event->type)
-        {
+    if (event->xany.window == mainWindow->window) {
+        switch (event->type) {
         case Expose:
             DrawMainWindow(mainWindow);
             break;
@@ -475,17 +445,17 @@ boolean MainWindowEventHandler(void *arg, XEvent* event)
                 mouse = &mainWindow->imiconstat.mouse;
             } else {
                 FcitxUIStatus *status;
-                for (status = (FcitxUIStatus*) utarray_front(&instance->uistats);
+                UT_array* uistats = FcitxInstanceGetUIStats(instance);
+                for (status = (FcitxUIStatus*) utarray_front(uistats);
                         status != NULL;
-                        status = (FcitxUIStatus*) utarray_next(&instance->uistats, status)
-                    )
-                {
+                        status = (FcitxUIStatus*) utarray_next(uistats, status)
+                    ) {
                     FcitxClassicUIStatus* privstat = GetPrivateStatus(status);
                     if (IsInRspArea(event->xbutton.x, event->xbutton.y, privstat))
                         mouse = &privstat->mouse;
                 }
             }
-            if  (SetMouseStatus(mainWindow, mouse, MOTION, RELEASE))
+            if (SetMouseStatus(mainWindow, mouse, MOTION, RELEASE))
                 DrawMainWindow(mainWindow);
             break;
         case LeaveNotify:
@@ -494,8 +464,7 @@ boolean MainWindowEventHandler(void *arg, XEvent* event)
             break;
         case ButtonPress:
             switch (event->xbutton.button) {
-            case Button1:
-            {
+            case Button1: {
                 mouse = NULL;
                 if (IsInRspArea(event->xbutton.x, event->xbutton.y, &mainWindow->logostat)) {
                     mouse = &mainWindow->logostat.mouse;
@@ -503,12 +472,10 @@ boolean MainWindowEventHandler(void *arg, XEvent* event)
                     classicui->iMainWindowOffsetX = event->xbutton.x;
                     classicui->iMainWindowOffsetY = event->xbutton.y;
 
-                    if (!ClassicUIMouseClick(mainWindow->owner, mainWindow->window, &classicui->iMainWindowOffsetX, &classicui->iMainWindowOffsetY))
-                    {
+                    if (!ClassicUIMouseClick(mainWindow->owner, mainWindow->window, &classicui->iMainWindowOffsetX, &classicui->iMainWindowOffsetY)) {
                         if (GetCurrentState(instance) == IS_CLOSED) {
                             EnableIM(instance, GetCurrentIC(instance), false);
-                        }
-                        else {
+                        } else {
                             CloseIM(instance, GetCurrentIC(instance));
                         }
                     }
@@ -518,23 +485,21 @@ boolean MainWindowEventHandler(void *arg, XEvent* event)
                     SwitchIM(instance, -1);
                 } else {
                     FcitxUIStatus *status;
-                    for (status = (FcitxUIStatus*) utarray_front(&instance->uistats);
+                    UT_array* uistats = FcitxInstanceGetUIStats(instance);
+                    for (status = (FcitxUIStatus*) utarray_front(uistats);
                             status != NULL;
-                            status = (FcitxUIStatus*) utarray_next(&instance->uistats, status)
-                        )
-                    {
+                            status = (FcitxUIStatus*) utarray_next(uistats, status)
+                        ) {
                         FcitxClassicUIStatus* privstat = GetPrivateStatus(status);
-                        if (IsInRspArea(event->xbutton.x, event->xbutton.y, privstat))
-                        {
+                        if (IsInRspArea(event->xbutton.x, event->xbutton.y, privstat)) {
                             mouse = &privstat->mouse;
                             UpdateStatus(instance, status->name);
                         }
                     }
                 }
-                if  (SetMouseStatus(mainWindow, mouse, PRESS, RELEASE))
+                if (SetMouseStatus(mainWindow, mouse, PRESS, RELEASE))
                     DrawMainWindow(mainWindow);
-                if (mouse == NULL)
-                {
+                if (mouse == NULL) {
                     classicui->iMainWindowOffsetX = event->xbutton.x;
                     classicui->iMainWindowOffsetY = event->xbutton.y;
                     ClassicUIMouseClick(mainWindow->owner, mainWindow->window, &classicui->iMainWindowOffsetX, &classicui->iMainWindowOffsetY);
@@ -542,8 +507,7 @@ boolean MainWindowEventHandler(void *arg, XEvent* event)
                 }
             }
             break;
-            case Button3:
-            {
+            case Button3: {
                 XlibMenu *mainMenuWindow = classicui->mainMenuWindow;
                 unsigned int height;
                 int sheight;
@@ -586,4 +550,4 @@ boolean MainWindowEventHandler(void *arg, XEvent* event)
     return false;
 }
 
-// kate: indent-mode cstyle; space-indent on; indent-width 0; 
+// kate: indent-mode cstyle; space-indent on; indent-width 0;
