@@ -73,11 +73,10 @@ CONFIG_DESC_DEFINE(GetSkinDesc, "skin.desc")
 int LoadSkinConfig(FcitxSkin* sc, char** skinType)
 {
     FILE    *fp;
-    char  buf[PATH_MAX]={0};
+    char  buf[PATH_MAX] = {0};
     boolean    isreload = False;
     int ret = 0;
-    if (sc->config.configFile)
-    {
+    if (sc->config.configFile) {
         utarray_done(&sc->skinMainBar.skinPlacement);
         FreeConfigFile(sc->config.configFile);
         free(sc->skinInfo.skinName);
@@ -104,57 +103,41 @@ int LoadSkinConfig(FcitxSkin* sc, char** skinType)
 reload:
     //获取配置文件的绝对路径
     {
-        if (!isreload)
-        {
+        if (!isreload) {
             snprintf(buf, PATH_MAX, "%s/fcitx_skin.conf", *skinType);
-            buf[PATH_MAX-1] ='\0';
-            size_t len;
-            char ** path = GetXDGPath(&len, "XDG_CONFIG_HOME", ".config", PACKAGE "/skin" , DATADIR, PACKAGE "/skin" );
+            buf[PATH_MAX - 1] = '\0';
 
-            fp = GetXDGFile(buf, path, "r", len, NULL);
-            FreeXDGPath(path);
-        }
-        else
-        {
+            fp = GetXDGFileWithPrefix("skin", buf, "r", NULL);
+        } else {
             FcitxLog(INFO, PKGDATADIR "/skin/default/fcitx_skin.conf");
-            fp = fopen( PKGDATADIR "/skin/default/fcitx_skin.conf", "r");
+            fp = fopen(PKGDATADIR "/skin/default/fcitx_skin.conf", "r");
         }
     }
 
-    if (fp)
-    {
+    if (fp) {
         ConfigFile *cfile;
         ConfigFileDesc* skinDesc = GetSkinDesc();
-        if (sc->config.configFile == NULL)
-        {
+        if (sc->config.configFile == NULL) {
             cfile = ParseConfigFileFp(fp, skinDesc);
-        }
-        else
-        {
+        } else {
             cfile = sc->config.configFile;
             cfile = ParseIniFp(fp, cfile);
         }
-        if (!cfile)
-        {
+        if (!cfile) {
             fclose(fp);
             fp = NULL;
-        }
-        else
-        {
+        } else {
             FcitxSkinConfigBind(sc, cfile, skinDesc);
             ConfigBindSync((GenericConfig*)sc);
         }
     }
 
-    if (!fp)
-    {
-        if (isreload)
-        {
+    if (!fp) {
+        if (isreload) {
             FcitxLog(FATAL, _("Can not load default skin, is installion correct?"));
             perror("fopen");
             ret = 1;    // 如果安装目录里面也没有配置文件，那就只好告诉用户，无法运行了
-        }
-        else {
+        } else {
             perror("fopen");
             FcitxLog(WARNING, _("Can not load skin %s, return to default"), *skinType);
             if (*skinType)
@@ -182,28 +165,25 @@ SkinImage* LoadImage(FcitxSkin* sc, const char* name, boolean fallback)
     HASH_FIND_STR(sc->imageTable, name, image);
     if (image != NULL)
         return image;
-    if ( strlen(name) > 0 && strcmp( name ,"NONE") !=0)
-    {
+    if (strlen(name) > 0 && strcmp(name , "NONE") != 0) {
         char *skintype = strdup(*sc->skinType);
         size_t len;
-        char ** path = GetXDGPath(&len, "XDG_CONFIG_HOME", ".config", PACKAGE "/skin" , DATADIR, PACKAGE "/skin" );
+        char ** path = GetXDGPath(&len, "XDG_CONFIG_HOME", ".config", PACKAGE "/skin" , DATADIR, PACKAGE "/skin");
         char *filename;
         while (True) {
             snprintf(buf, PATH_MAX, "%s/%s", skintype, name);
-            buf[PATH_MAX-1] ='\0';
+            buf[PATH_MAX - 1] = '\0';
 
             FILE* fp = GetXDGFile(buf, path, "r", len, &filename);
 
             Bool flagNoFile = (fp == NULL);
-            if (fp)
-            {
+            if (fp) {
                 fclose(fp);
 
-                png=cairo_image_surface_create_from_png(filename);
+                png = cairo_image_surface_create_from_png(filename);
                 break;
             }
-            if (flagNoFile && (!fallback || strcmp(skintype, "default") == 0))
-            {
+            if (flagNoFile && (!fallback || strcmp(skintype, "default") == 0)) {
                 png = NULL;
                 break;
             }
@@ -217,8 +197,7 @@ SkinImage* LoadImage(FcitxSkin* sc, const char* name, boolean fallback)
         FreeXDGPath(path);
     }
 
-    if (png != NULL)
-    {
+    if (png != NULL) {
         image = fcitx_malloc0(sizeof(SkinImage));
         image->name = strdup(name);
         image->image = png;
@@ -263,8 +242,8 @@ void DrawResizableBackground(cairo_t *c,
     /* part 1 */
     cairo_save(c);
     cairo_translate(c, 0, height - marginBottom);
-    cairo_set_source_surface(c, background, 0, -marginTop -resizeHeight);
-    cairo_rectangle (c, 0, 0, marginLeft, marginBottom);
+    cairo_set_source_surface(c, background, 0, -marginTop - resizeHeight);
+    cairo_rectangle(c, 0, 0, marginLeft, marginBottom);
     cairo_clip(c);
     cairo_paint(c);
     cairo_restore(c);
@@ -272,8 +251,8 @@ void DrawResizableBackground(cairo_t *c,
     /* part 3 */
     cairo_save(c);
     cairo_translate(c, width - marginRight, height - marginBottom);
-    cairo_set_source_surface(c, background, -marginLeft -resizeWidth, -marginTop -resizeHeight);
-    cairo_rectangle (c, 0, 0, marginRight, marginBottom);
+    cairo_set_source_surface(c, background, -marginLeft - resizeWidth, -marginTop - resizeHeight);
+    cairo_rectangle(c, 0, 0, marginRight, marginBottom);
     cairo_clip(c);
     cairo_paint(c);
     cairo_restore(c);
@@ -281,7 +260,7 @@ void DrawResizableBackground(cairo_t *c,
 
     /* part 7 */
     cairo_save(c);
-    cairo_rectangle (c, 0, 0, marginLeft, marginTop);
+    cairo_rectangle(c, 0, 0, marginLeft, marginTop);
     cairo_clip(c);
     cairo_paint(c);
     cairo_restore(c);
@@ -289,78 +268,73 @@ void DrawResizableBackground(cairo_t *c,
     /* part 9 */
     cairo_save(c);
     cairo_translate(c, width - marginRight, 0);
-    cairo_set_source_surface(c, background, -marginLeft -resizeWidth, 0);
-    cairo_rectangle (c, 0, 0, marginRight, marginTop);
+    cairo_set_source_surface(c, background, -marginLeft - resizeWidth, 0);
+    cairo_rectangle(c, 0, 0, marginRight, marginTop);
     cairo_clip(c);
     cairo_paint(c);
     cairo_restore(c);
 
     /* part 2 & 8 */
     {
-        if ( fillH == F_COPY)
-        {
-            int repaint_times=(width - marginLeft - marginRight)/resizeWidth;
-            int remain_width=(width - marginLeft - marginRight)% resizeWidth;
-            int i=0;
+        if (fillH == F_COPY) {
+            int repaint_times = (width - marginLeft - marginRight) / resizeWidth;
+            int remain_width = (width - marginLeft - marginRight) % resizeWidth;
+            int i = 0;
 
-            for (i=0;i<repaint_times;i++)
-            {
+            for (i = 0; i < repaint_times; i++) {
                 /* part 8 */
                 cairo_save(c);
-                cairo_translate(c, marginLeft + i*resizeWidth, 0);
+                cairo_translate(c, marginLeft + i * resizeWidth, 0);
                 cairo_set_source_surface(c, background, -marginLeft, 0);
-                cairo_rectangle (c,0,0,resizeWidth, marginTop);
+                cairo_rectangle(c, 0, 0, resizeWidth, marginTop);
                 cairo_clip(c);
                 cairo_paint(c);
                 cairo_restore(c);
-                
+
                 /* part 2 */
                 cairo_save(c);
-                cairo_translate(c,  marginLeft + i*resizeWidth, height - marginBottom);
-                cairo_set_source_surface(c, background,  -marginLeft, -marginTop -resizeHeight);
-                cairo_rectangle (c,0,0,resizeWidth,marginBottom);
+                cairo_translate(c,  marginLeft + i * resizeWidth, height - marginBottom);
+                cairo_set_source_surface(c, background,  -marginLeft, -marginTop - resizeHeight);
+                cairo_rectangle(c, 0, 0, resizeWidth, marginBottom);
                 cairo_clip(c);
                 cairo_paint(c);
                 cairo_restore(c);
             }
 
-            if (remain_width != 0)
-            {
+            if (remain_width != 0) {
                 /* part 8 */
                 cairo_save(c);
-                cairo_translate(c, marginLeft + repaint_times*resizeWidth, 0);
+                cairo_translate(c, marginLeft + repaint_times * resizeWidth, 0);
                 cairo_set_source_surface(c, background, -marginLeft, 0);
-                cairo_rectangle (c,0,0,remain_width, marginTop);
+                cairo_rectangle(c, 0, 0, remain_width, marginTop);
                 cairo_clip(c);
                 cairo_paint(c);
                 cairo_restore(c);
-                
+
                 /* part 2 */
                 cairo_save(c);
-                cairo_translate(c,  marginLeft + repaint_times*resizeWidth, height - marginBottom);
-                cairo_set_source_surface(c, background,  -marginLeft, -marginTop -resizeHeight);
-                cairo_rectangle (c,0,0,remain_width,marginBottom);
+                cairo_translate(c,  marginLeft + repaint_times * resizeWidth, height - marginBottom);
+                cairo_set_source_surface(c, background,  -marginLeft, -marginTop - resizeHeight);
+                cairo_rectangle(c, 0, 0, remain_width, marginBottom);
                 cairo_clip(c);
                 cairo_paint(c);
                 cairo_restore(c);
             }
-        }
-        else
-        {
+        } else {
             cairo_save(c);
             cairo_translate(c, marginLeft, 0);
-            cairo_scale(c, (double)(width - marginLeft - marginRight)/(double)resizeWidth, 1);
+            cairo_scale(c, (double)(width - marginLeft - marginRight) / (double)resizeWidth, 1);
             cairo_set_source_surface(c, background, -marginLeft, 0);
-            cairo_rectangle (c,0,0, resizeWidth, marginTop);
+            cairo_rectangle(c, 0, 0, resizeWidth, marginTop);
             cairo_clip(c);
             cairo_paint(c);
             cairo_restore(c);
-                        
+
             cairo_save(c);
             cairo_translate(c, marginLeft, height - marginBottom);
-            cairo_scale(c, (double)(width - marginLeft - marginRight)/(double)resizeWidth, 1);
-            cairo_set_source_surface(c, background, -marginLeft, -marginTop -resizeHeight);
-            cairo_rectangle (c,0,0, resizeWidth, marginBottom);
+            cairo_scale(c, (double)(width - marginLeft - marginRight) / (double)resizeWidth, 1);
+            cairo_set_source_surface(c, background, -marginLeft, -marginTop - resizeHeight);
+            cairo_rectangle(c, 0, 0, resizeWidth, marginBottom);
             cairo_clip(c);
             cairo_paint(c);
             cairo_restore(c);
@@ -368,71 +342,66 @@ void DrawResizableBackground(cairo_t *c,
     }
 
     /* part 4 & 6 */
-    {        
-        if ( fillV == F_COPY)
-        {
-            int repaint_times=(height - marginTop - marginBottom)/resizeHeight;
-            int remain_height=(height - marginTop - marginBottom)% resizeHeight;
-            int i=0;
+    {
+        if (fillV == F_COPY) {
+            int repaint_times = (height - marginTop - marginBottom) / resizeHeight;
+            int remain_height = (height - marginTop - marginBottom) % resizeHeight;
+            int i = 0;
 
-            for (i=0;i<repaint_times;i++)
-            {
+            for (i = 0; i < repaint_times; i++) {
                 /* part 4 */
                 cairo_save(c);
-                cairo_translate(c, 0, marginTop + i*resizeHeight);
+                cairo_translate(c, 0, marginTop + i * resizeHeight);
                 cairo_set_source_surface(c, background, 0, -marginTop);
-                cairo_rectangle (c,0,0, marginLeft, resizeHeight);
+                cairo_rectangle(c, 0, 0, marginLeft, resizeHeight);
                 cairo_clip(c);
                 cairo_paint(c);
                 cairo_restore(c);
-                
+
                 /* part 6 */
                 cairo_save(c);
-                cairo_translate(c, width - marginRight,  marginTop + i*resizeHeight);
-                cairo_set_source_surface(c, background, -marginLeft -resizeWidth,  -marginTop);
-                cairo_rectangle (c,0,0,marginRight,resizeHeight);
+                cairo_translate(c, width - marginRight,  marginTop + i * resizeHeight);
+                cairo_set_source_surface(c, background, -marginLeft - resizeWidth,  -marginTop);
+                cairo_rectangle(c, 0, 0, marginRight, resizeHeight);
                 cairo_clip(c);
                 cairo_paint(c);
                 cairo_restore(c);
             }
 
-            if (remain_height != 0)
-            {
+            if (remain_height != 0) {
                 /* part 8 */
                 cairo_save(c);
-                cairo_translate(c, 0, marginTop + repaint_times*resizeHeight);
+                cairo_translate(c, 0, marginTop + repaint_times * resizeHeight);
                 cairo_set_source_surface(c, background, 0, -marginTop);
-                cairo_rectangle (c,0,0, marginLeft, remain_height);
+                cairo_rectangle(c, 0, 0, marginLeft, remain_height);
                 cairo_clip(c);
                 cairo_paint(c);
                 cairo_restore(c);
-                
+
                 /* part 2 */
                 cairo_save(c);
-                cairo_translate(c,  width - marginRight,  marginTop + repaint_times*resizeHeight);
-                cairo_set_source_surface(c, background, -marginLeft -resizeWidth,  -marginTop);
-                cairo_rectangle (c,0,0,marginRight, remain_height);
+                cairo_translate(c,  width - marginRight,  marginTop + repaint_times * resizeHeight);
+                cairo_set_source_surface(c, background, -marginLeft - resizeWidth,  -marginTop);
+                cairo_rectangle(c, 0, 0, marginRight, remain_height);
                 cairo_clip(c);
                 cairo_paint(c);
                 cairo_restore(c);
             }
-        }
-        else
-        {
+        } else {
             cairo_save(c);
             cairo_translate(c, 0, marginTop);
-            cairo_scale(c, 1, (double)(height - marginTop - marginBottom)/(double)resizeHeight);
+            cairo_scale(c, 1, (double)(height - marginTop - marginBottom) / (double)resizeHeight);
             cairo_set_source_surface(c, background, 0, -marginTop);
-            cairo_rectangle (c,0,0, marginLeft, resizeHeight);
+            cairo_rectangle(c, 0, 0, marginLeft, resizeHeight);
             cairo_clip(c);
             cairo_paint(c);
             cairo_restore(c);
-                        
+
             cairo_save(c);
             cairo_translate(c, width - marginRight, marginTop);
-            cairo_scale(c, 1, (double)(height - marginTop - marginBottom)/(double)resizeHeight);
-            cairo_set_source_surface(c, background, -marginLeft -resizeWidth, -marginTop);
-            cairo_rectangle (c,0,0, marginRight, resizeHeight);
+            cairo_scale(c, 1, (double)(height - marginTop - marginBottom) / (double)resizeHeight);
+            cairo_set_source_surface(c, background, -marginLeft - resizeWidth, -marginTop);
+            cairo_rectangle(c, 0, 0, marginRight, resizeHeight);
             cairo_clip(c);
             cairo_paint(c);
             cairo_restore(c);
@@ -444,48 +413,40 @@ void DrawResizableBackground(cairo_t *c,
         int repaintH = 0, repaintV = 0;
         int remainW = 0, remainH = 0;
         double scaleX = 1.0, scaleY = 1.0;
-        
-        if (fillH == F_COPY)
-        {
-            repaintH = (width - marginLeft - marginRight)/resizeWidth + 1;
-            remainW = (width - marginLeft - marginRight)% resizeWidth;
-        }
-        else
-        {
+
+        if (fillH == F_COPY) {
+            repaintH = (width - marginLeft - marginRight) / resizeWidth + 1;
+            remainW = (width - marginLeft - marginRight) % resizeWidth;
+        } else {
             repaintH = 1;
-            scaleX = (double)(width - marginLeft - marginRight)/(double)resizeWidth;
+            scaleX = (double)(width - marginLeft - marginRight) / (double)resizeWidth;
         }
-        
-        if (fillV == F_COPY)
-        {            
-            repaintV = (height - marginTop - marginBottom)/(double)resizeHeight + 1;
-            remainH = (height - marginTop - marginBottom)%resizeHeight;
-        }
-        else
-        {
+
+        if (fillV == F_COPY) {
+            repaintV = (height - marginTop - marginBottom) / (double)resizeHeight + 1;
+            remainH = (height - marginTop - marginBottom) % resizeHeight;
+        } else {
             repaintV = 1;
-            scaleY = (double)(height - marginTop - marginBottom)/(double)resizeHeight;
+            scaleY = (double)(height - marginTop - marginBottom) / (double)resizeHeight;
         }
-        
+
 
         int i, j;
-        for (i = 0; i < repaintH; i ++)
-        {
-            for (j = 0; j < repaintV; j ++)
-            {
+        for (i = 0; i < repaintH; i ++) {
+            for (j = 0; j < repaintV; j ++) {
                 cairo_save(c);
                 cairo_translate(c, marginLeft + i * resizeWidth , marginTop + j * resizeHeight);
                 cairo_scale(c, scaleX, scaleY);
                 cairo_set_source_surface(c, background, -marginLeft, -marginTop);
-                int w = resizeWidth,h = resizeHeight;
+                int w = resizeWidth, h = resizeHeight;
 
                 if (fillV == F_COPY && j == repaintV - 1)
                     h = remainH;
-                
-                if (fillH == F_COPY && i == repaintH -1 )
+
+                if (fillH == F_COPY && i == repaintH - 1)
                     w = remainW;
-                
-                cairo_rectangle (c,0,0, w, h);
+
+                cairo_rectangle(c, 0, 0, w, h);
                 cairo_clip(c);
                 cairo_paint(c);
                 cairo_restore(c);
@@ -499,7 +460,7 @@ void DestroyImage(cairo_surface_t ** png)
 {
     if (png != NULL)
         cairo_surface_destroy(*png);
-    *png=NULL;
+    *png = NULL;
 }
 
 /**
@@ -511,23 +472,19 @@ void LoadInputMessage(FcitxSkin* sc, InputWindow* inputWindow, const char* font)
 
     ConfigColor cursorColor = sc->skinInputBar.cursorColor;
 
-    if (inputWindow->c_back)
-    {
+    if (inputWindow->c_back) {
         cairo_destroy(inputWindow->c_back);
         inputWindow->c_back = NULL;
     }
 
-    for (i = 0; i < 7 ; i ++)
-    {
-        if (inputWindow->c_font[i])
-        {
+    for (i = 0; i < 7 ; i ++) {
+        if (inputWindow->c_font[i]) {
             cairo_destroy(inputWindow->c_font[i]);
             inputWindow->c_font[i] = NULL;
         }
     }
     inputWindow->c_font[7] = NULL;
-    if (inputWindow->c_cursor)
-    {
+    if (inputWindow->c_cursor) {
         cairo_destroy(inputWindow->c_cursor);
         inputWindow->c_cursor = NULL;
     }
@@ -535,8 +492,7 @@ void LoadInputMessage(FcitxSkin* sc, InputWindow* inputWindow, const char* font)
     //输入条背景图画笔
     inputWindow->c_back = cairo_create(inputWindow->cs_input_bar);
 
-    for (i = 0; i < 7 ; i ++)
-    {
+    for (i = 0; i < 7 ; i ++) {
         inputWindow->c_font[i] = cairo_create(inputWindow->cs_input_bar);
         fcitx_cairo_set_color(inputWindow->c_font[i], &sc->skinFont.fontColor[i]);
 #ifndef _ENABLE_PANGO
@@ -546,9 +502,9 @@ void LoadInputMessage(FcitxSkin* sc, InputWindow* inputWindow, const char* font)
     inputWindow->c_font[7] = inputWindow->c_font[0];
 
     //光标画笔
-    inputWindow->c_cursor=cairo_create(inputWindow->cs_input_bar);
+    inputWindow->c_cursor = cairo_create(inputWindow->cs_input_bar);
     fcitx_cairo_set_color(inputWindow->c_cursor, &cursorColor);
-    cairo_set_line_width (inputWindow->c_cursor, 1);
+    cairo_set_line_width(inputWindow->c_cursor, 1);
 }
 
 void DrawImage(cairo_t *c, cairo_surface_t * png, int x, int y, MouseE mouse)
@@ -558,30 +514,25 @@ void DrawImage(cairo_t *c, cairo_surface_t * png, int x, int y, MouseE mouse)
 
     cairo_save(c);
 
-    if (mouse == MOTION)
-    {
-        cairo_set_source_surface(c,png, x, y);
-        cairo_paint_with_alpha(c,0.7);
+    if (mouse == MOTION) {
+        cairo_set_source_surface(c, png, x, y);
+        cairo_paint_with_alpha(c, 0.7);
 
-    }
-    else if (mouse == PRESS)
-    {
+    } else if (mouse == PRESS) {
         cairo_set_operator(c, CAIRO_OPERATOR_OVER);
-        cairo_translate(c, x+(int)(cairo_image_surface_get_width(png)*0.2/2), y+(int)(cairo_image_surface_get_height(png)*0.2/2));
+        cairo_translate(c, x + (int)(cairo_image_surface_get_width(png) * 0.2 / 2), y + (int)(cairo_image_surface_get_height(png) * 0.2 / 2));
         cairo_scale(c, 0.8, 0.8);
-        cairo_set_source_surface(c,png,0,0);
+        cairo_set_source_surface(c, png, 0, 0);
         cairo_paint(c);
-    }
-    else //if( img.mouse == RELEASE)
-    {
-        cairo_set_source_surface(c,png, x, y);
+    } else { //if( img.mouse == RELEASE)
+        cairo_set_source_surface(c, png, x, y);
         cairo_paint(c);
     }
 
     cairo_restore(c);
 }
 
-void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messages * msgup, Messages *msgdown ,unsigned int * iheight, unsigned int *iwidth)
+void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messages * msgup, Messages *msgdown , unsigned int * iheight, unsigned int *iwidth)
 {
     int i;
     char *strUp[MAX_MESSAGE_COUNT];
@@ -590,11 +541,11 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
     int posDownX[MAX_MESSAGE_COUNT], posDownY[MAX_MESSAGE_COUNT];
     int oldHeight = *iheight, oldWidth = *iwidth;
     int newHeight = 0, newWidth = 0;
-    int cursor_pos=0;
+    int cursor_pos = 0;
     int inputWidth = 0, outputWidth = 0;
     int outputHeight = 0;
     cairo_t *c = NULL;
-    FcitxInputState* input = &inputWindow->owner->owner->input;
+    FcitxInputState* input = FcitxInstanceGetInputState(inputWindow->owner->owner);
     FcitxInstance* instance = inputWindow->owner->owner;
     int iChar = iCursorPos;
     int strWidth = 0, strHeight = 0;
@@ -612,8 +563,7 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
     SetFontContext(dummy, inputWindow->owner->font, sc->skinFont.fontSize);
 #endif
 
-    for (i = 0; i < GetMessageCount(msgup) ; i++)
-    {
+    for (i = 0; i < GetMessageCount(msgup) ; i++) {
         char *trans = ProcessOutputFilter(instance, GetMessageString(msgup, i));
         if (trans)
             strUp[i] = trans;
@@ -625,21 +575,18 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
 
         posUpY[i] = sc->skinInputBar.marginTop + sc->skinInputBar.iInputPos - strHeight;
         inputWidth += strWidth;
-        if (input->bShowCursor)
-        {
+        if (FcitxInputStateGetShowCursor(input)) {
             int length = strlen(GetMessageString(msgup, i));
-            if (iChar >= 0)
-            {
-                if (iChar < length)
-                {
+            if (iChar >= 0) {
+                if (iChar < length) {
                     char strTemp[MESSAGE_MAX_LENGTH];
                     char *strGBKT = NULL;
                     strncpy(strTemp, strUp[i], iChar);
                     strTemp[iChar] = '\0';
                     strGBKT = strTemp;
                     StringSizeWithContext(inputWindow->c_font[GetMessageType(msgup, i)], strGBKT, &strWidth, &strHeight);
-                    cursor_pos= posUpX[i]
-                                + strWidth + 2;
+                    cursor_pos = posUpX[i]
+                                 + strWidth + 2;
                 }
                 iChar -= length;
             }
@@ -653,22 +600,18 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
     outputWidth = 0;
     outputHeight = 0;
     int currentX = 0;
-    for (i = 0; i < GetMessageCount(msgdown) ; i++)
-    {
+    for (i = 0; i < GetMessageCount(msgdown) ; i++) {
         char *trans = ProcessOutputFilter(instance, GetMessageString(msgdown, i));
         if (trans)
             strDown[i] = trans;
         else
             strDown[i] = GetMessageString(msgdown, i);
 
-        if (inputWindow->owner->bVerticalList) /* vertical */
-        {
-            if (GetMessageType(msgdown, i) == MSG_INDEX)
-            {
+        if (inputWindow->owner->bVerticalList) { /* vertical */
+            if (GetMessageType(msgdown, i) == MSG_INDEX) {
                 if (currentX > outputWidth)
                     outputWidth = currentX;
-                if (i != 0)
-                {
+                if (i != 0) {
                     outputHeight += sc->skinFont.fontSize + 2;
                     currentX = 0;
                 }
@@ -677,9 +620,7 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
             StringSizeWithContext(inputWindow->c_font[GetMessageType(msgdown, i)], strDown[i], &strWidth, &strHeight);
             currentX += strWidth;
             posDownY[i] =  sc->skinInputBar.marginTop + sc->skinInputBar.iOutputPos + outputHeight - strHeight;
-        }
-        else /* horizontal */
-        {
+        } else { /* horizontal */
             posDownX[i] = sc->skinInputBar.marginLeft + outputWidth;
             StringSizeWithContext(inputWindow->c_font[GetMessageType(msgdown, i)], strDown[i], &strWidth, &strHeight);
             posDownY[i] = sc->skinInputBar.marginTop + sc->skinInputBar.iOutputPos - strHeight;
@@ -691,29 +632,25 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
 
     newHeight = sc->skinInputBar.marginTop + sc->skinInputBar.iOutputPos + outputHeight + sc->skinInputBar.marginBottom;
 
-    newWidth = (inputWidth<outputWidth)?outputWidth:inputWidth;
-    newWidth+=sc->skinInputBar.marginLeft+sc->skinInputBar.marginRight;
+    newWidth = (inputWidth < outputWidth) ? outputWidth : inputWidth;
+    newWidth += sc->skinInputBar.marginLeft + sc->skinInputBar.marginRight;
 
     /* round to ROUND_SIZE in order to decrease resize */
-    newWidth =  (newWidth / ROUND_SIZE) * ROUND_SIZE + ROUND_SIZE;
+    newWidth = (newWidth / ROUND_SIZE) * ROUND_SIZE + ROUND_SIZE;
 
     //输入条长度应该比背景图长度要长,比最大长度要短
-    newWidth=(newWidth>=INPUT_BAR_MAX_WIDTH)?INPUT_BAR_MAX_WIDTH:newWidth;
-    if (inputWindow->owner->bVerticalList) /* vertical */
-    {
-        newWidth = (newWidth < INPUT_BAR_VMIN_WIDTH)?INPUT_BAR_VMIN_WIDTH:newWidth;
-    }
-    else
-    {
-        newWidth = (newWidth < INPUT_BAR_HMIN_WIDTH)?INPUT_BAR_HMIN_WIDTH:newWidth;
+    newWidth = (newWidth >= INPUT_BAR_MAX_WIDTH) ? INPUT_BAR_MAX_WIDTH : newWidth;
+    if (inputWindow->owner->bVerticalList) { /* vertical */
+        newWidth = (newWidth < INPUT_BAR_VMIN_WIDTH) ? INPUT_BAR_VMIN_WIDTH : newWidth;
+    } else {
+        newWidth = (newWidth < INPUT_BAR_HMIN_WIDTH) ? INPUT_BAR_HMIN_WIDTH : newWidth;
     }
 
     *iwidth = newWidth;
     *iheight = newHeight;
 
-    if (oldHeight != newHeight || oldWidth != newWidth)
-    {
-        c=cairo_create(inputWindow->cs_input_back);
+    if (oldHeight != newHeight || oldWidth != newWidth) {
+        c = cairo_create(inputWindow->cs_input_back);
         DrawResizableBackground(c, inputimg->image, newHeight, newWidth,
                                 sc->skinInputBar.marginLeft,
                                 sc->skinInputBar.marginTop,
@@ -728,7 +665,7 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
     c = cairo_create(inputWindow->cs_input_bar);
     cairo_set_source_surface(c, inputWindow->cs_input_back, 0, 0);
     cairo_save(c);
-    cairo_rectangle (c, 0, 0, newWidth, newHeight);
+    cairo_rectangle(c, 0, 0, newWidth, newHeight);
     cairo_set_operator(c, CAIRO_OPERATOR_SOURCE);
     cairo_clip(c);
     cairo_paint(c);
@@ -737,39 +674,35 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
     cairo_set_operator(c, CAIRO_OPERATOR_OVER);
 
 
-    if (input->bShowCursor )
-    {
+    if (FcitxInputStateGetShowCursor(input)) {
         //画向前向后箭头
-        if (prev && next )
-        {
+        if (prev && next) {
             cairo_set_source_surface(inputWindow->c_back, prev->image,
                                      newWidth - sc->skinInputBar.iBackArrowX ,
                                      sc->skinInputBar.iBackArrowY);
-            if (CandidateWordHasPrev(input->candList))
+            if (CandidateWordHasPrev(FcitxInputStateGetCandidateList(input)))
                 cairo_paint(inputWindow->c_back);
             else
-                cairo_paint_with_alpha(inputWindow->c_back,0.5);
+                cairo_paint_with_alpha(inputWindow->c_back, 0.5);
 
             //画向前箭头
             cairo_set_source_surface(inputWindow->c_back, next->image,
                                      newWidth - sc->skinInputBar.iForwardArrowX ,
                                      sc->skinInputBar.iForwardArrowY);
-            if (CandidateWordHasNext(input->candList))
+            if (CandidateWordHasNext(FcitxInputStateGetCandidateList(input)))
                 cairo_paint(inputWindow->c_back);
             else
-                cairo_paint_with_alpha(inputWindow->c_back,0.5);
+                cairo_paint_with_alpha(inputWindow->c_back, 0.5);
         }
     }
 
-    for (i = 0; i < GetMessageCount(msgup) ; i++)
-    {
+    for (i = 0; i < GetMessageCount(msgup) ; i++) {
         OutputStringWithContext(inputWindow->c_font[GetMessageType(msgup, i)], strUp[i], posUpX[i], posUpY[i]);
         if (strUp[i] != GetMessageString(msgup, i))
             free(strUp[i]);
     }
 
-    for (i = 0; i < GetMessageCount(msgdown) ; i++)
-    {
+    for (i = 0; i < GetMessageCount(msgdown) ; i++) {
         OutputStringWithContext(inputWindow->c_font[GetMessageType(msgdown, i)], strDown[i], posDownX[i], posDownY[i]);
         if (strDown[i] != GetMessageString(msgdown, i))
             free(strDown[i]);
@@ -778,10 +711,9 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
     ResetFontContext();
 
     //画光标
-    if (input->bShowCursor )
-    {
-        cairo_move_to(inputWindow->c_cursor,cursor_pos,sc->skinInputBar.marginTop + sc->skinInputBar.iInputPos);
-        cairo_line_to(inputWindow->c_cursor,cursor_pos,sc->skinInputBar.marginTop + sc->skinInputBar.iInputPos - FontHeightWithContext(inputWindow->c_font[0]) - 4);
+    if (FcitxInputStateGetShowCursor(input)) {
+        cairo_move_to(inputWindow->c_cursor, cursor_pos, sc->skinInputBar.marginTop + sc->skinInputBar.iInputPos);
+        cairo_line_to(inputWindow->c_cursor, cursor_pos, sc->skinInputBar.marginTop + sc->skinInputBar.iInputPos - FontHeightWithContext(inputWindow->c_font[0]) - 4);
         cairo_stroke(inputWindow->c_cursor);
     }
 
@@ -793,7 +725,7 @@ void DrawInputBar(FcitxSkin* sc, InputWindow* inputWindow, int iCursorPos, Messa
 void DisplaySkin(FcitxClassicUI* classicui, char * skinname)
 {
     char *pivot = classicui->skinType;
-    classicui->skinType= strdup(skinname);
+    classicui->skinType = strdup(skinname);
     if (pivot)
         free(pivot);
 
@@ -807,9 +739,9 @@ void DisplaySkin(FcitxClassicUI* classicui, char * skinname)
 
     LoadInputMessage(&classicui->skin, classicui->inputWindow, classicui->font);
 
-    DrawMainWindow (classicui->mainWindow);
-    DrawInputWindow (classicui->inputWindow);
-    DrawTrayWindow (classicui->trayWindow);
+    DrawMainWindow(classicui->mainWindow);
+    DrawInputWindow(classicui->inputWindow);
+    DrawTrayWindow(classicui->trayWindow);
 
     SaveClassicUIConfig(classicui);
 }
@@ -817,8 +749,7 @@ void DisplaySkin(FcitxClassicUI* classicui, char * skinname)
 void UnloadImage(FcitxSkin* skin)
 {
     SkinImage *images = skin->imageTable;
-    while (images)
-    {
+    while (images) {
         SkinImage* curimage = images;
         HASH_DEL(images, curimage);
         free(curimage->name);
@@ -842,35 +773,29 @@ void LoadSkinDirectory(FcitxClassicUI* classicui)
     struct stat fileStat;
     size_t len;
     char pathBuf[PATH_MAX];
-    char **skinPath = GetXDGPath(&len, "XDG_CONFIG_HOME", ".config", PACKAGE "/skin" , DATADIR, PACKAGE "/skin" );
-    for (i = 0; i< len; i++)
-    {
+    char **skinPath = GetXDGPath(&len, "XDG_CONFIG_HOME", ".config", PACKAGE "/skin" , DATADIR, PACKAGE "/skin");
+    for (i = 0; i < len; i++) {
         dir = opendir(skinPath[i]);
         if (dir == NULL)
             continue;
 
-        while ((drt = readdir(dir)) != NULL)
-        {
+        while ((drt = readdir(dir)) != NULL) {
             if (strcmp(drt->d_name , ".") == 0 || strcmp(drt->d_name, "..") == 0)
                 continue;
-            sprintf(pathBuf,"%s/%s",skinPath[i],drt->d_name);
+            sprintf(pathBuf, "%s/%s", skinPath[i], drt->d_name);
 
-            if ( stat(pathBuf,&fileStat) == -1)
-            {
+            if (stat(pathBuf, &fileStat) == -1) {
                 continue;
             }
-            if ( fileStat.st_mode & S_IFDIR)
-            {
+            if (fileStat.st_mode & S_IFDIR) {
                 /* check duplicate name */
                 int j = 0;
-                for (;j<skinBuf->i;j++)
-                {
+                for (; j < skinBuf->i; j++) {
                     char **name = (char**) utarray_eltptr(skinBuf, j);
                     if (strcmp(*name, drt->d_name) == 0)
                         break;
                 }
-                if (j == skinBuf->i)
-                {
+                if (j == skinBuf->i) {
                     char *temp = drt->d_name;
                     utarray_push_back(skinBuf, &temp);
                 }
@@ -915,12 +840,10 @@ void UpdateSkinMenuShell(FcitxUIMenu* menu)
     char **s;
     int i = 0;
 
-    for ( s = (char**) utarray_front(&classicui->skinBuf);
+    for (s = (char**) utarray_front(&classicui->skinBuf);
             s != NULL;
-            s = (char**) utarray_next(&classicui->skinBuf, s))
-    {
-        if (strcmp(*s, classicui->skinType) == 0)
-        {
+            s = (char**) utarray_next(&classicui->skinBuf, s)) {
+        if (strcmp(*s, classicui->skinType) == 0) {
             menu->mark = i;
         }
         AddMenuShell(menu, *s, MENUTYPE_SIMPLE, NULL);
@@ -936,8 +859,7 @@ void ParsePlacement(UT_array* sps, char* placment)
     utarray_clear(sps);
     for (str = (char**) utarray_front(array);
             str != NULL;
-            str = (char**) utarray_next(array, str))
-    {
+            str = (char**) utarray_next(array, str)) {
         char* s = *str;
         char* p = strchr(s, ':');
         if (p == NULL)
@@ -949,7 +871,7 @@ void ParsePlacement(UT_array* sps, char* placment)
         SkinPlacement sp;
         strncpy(sp.name, s, len);
         sp.name[len] = '\0';
-        int ret = sscanf(p+1, "%d,%d", &sp.x, &sp.y);
+        int ret = sscanf(p + 1, "%d,%d", &sp.x, &sp.y);
         if (ret != 2)
             continue;
         utarray_push_back(sps, &sp);
